summaryrefslogtreecommitdiff
path: root/chromium/content/public/browser/devtools_agent_host_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/content/public/browser/devtools_agent_host_client.h')
-rw-r--r--chromium/content/public/browser/devtools_agent_host_client.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/chromium/content/public/browser/devtools_agent_host_client.h b/chromium/content/public/browser/devtools_agent_host_client.h
index 3cd124c38b2..c447a2652e3 100644
--- a/chromium/content/public/browser/devtools_agent_host_client.h
+++ b/chromium/content/public/browser/devtools_agent_host_client.h
@@ -8,11 +8,11 @@
#include <string>
#include "content/common/content_export.h"
+class GURL;
namespace content {
class DevToolsAgentHost;
-class RenderFrameHost;
// DevToolsAgentHostClient can attach to a DevToolsAgentHost and start
// debugging it.
@@ -27,10 +27,9 @@ class CONTENT_EXPORT DevToolsAgentHostClient {
// This method is called when attached agent host is closed.
virtual void AgentHostClosed(DevToolsAgentHost* agent_host) = 0;
// Returns true if the client is allowed to attach to the given renderer.
// Note: this method may be called before navigation commits.
- virtual bool MayAttachToRenderer(content::RenderFrameHost* render_frame_host,
- bool is_webui);
+ virtual bool MayAttachToURL(const GURL& url, bool is_webui);
// Returns true if the client is allowed to attach to the browser agent host.
// Browser client is allowed to discover other DevTools targets and generally
@@ -27,10 +27,9 @@ class CONTENT_EXPORT DevToolsAgentHostClient {
// This method is called when attached agent host is closed.
virtual void AgentHostClosed(DevToolsAgentHost* agent_host) = 0;
- // Returns true if the client is allowed to attach to the given renderer.
+ // Returns true if the client is allowed to attach to the given URL.
// Note: this method may be called before navigation commits.